==> dapr-sdk-autogen-1.8.0-sources.jar: io/dapr/v1/AppCallbackHealthCheckGrpc.java <==
package io.dapr.v1;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 * <pre>
 * AppCallbackHealthCheck V1 is an optional extension to AppCallback V1 to implement
 * the HealthCheck method.
 * </pre>
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.42.1)",
    comments = "Source: appcallback.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class AppCallbackHealthCheckGrpc {

  private AppCallbackHealthCheckGrpc() {}

  public static final String SERVICE_NAME = "dapr.proto.runtime.v1.AppCallbackHealthCheck";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<com.google.protobuf.Empty,
      io.dapr.v1.DaprAppCallbackProtos.HealthCheckResponse> getHealthCheckMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "HealthCheck",
      requestType = com.google.protobuf.Empty.class,
      responseType = io.dapr.v1.DaprAppCallbackProtos.HealthCheckResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<com.google.protobuf.Empty,
      io.dapr.v1.DaprAppCallbackProtos.HealthCheckResponse> getHealthCheckMethod() {
    io.grpc.MethodDescriptor<com.google.protobuf.Empty, io.dapr.v1.DaprAppCallbackProtos.HealthCheckResponse> getHealthCheckMethod;
    if ((getHealthCheckMethod = AppCallbackHealthCheckGrpc.getHealthCheckMethod) == null) {
      synchronized (AppCallbackHealthCheckGrpc.class) {
        if ((getHealthCheckMethod = AppCallbackHealthCheckGrpc.getHealthCheckMethod) == null) {
          AppCallbackHealthCheckGrpc.getHealthCheckMethod = getHealthCheckMethod =
              io.grpc.MethodDescriptor.<com.google.protobuf.Empty, io.dapr.v1.DaprAppCallbackProtos.HealthCheckResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "HealthCheck"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.google.protobuf.Empty.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  io.dapr.v1.DaprAppCallbackProtos.HealthCheckResponse.getDefaultInstance()))
              .setSchemaDescriptor(new AppCallbackHealthCheckMethodDescriptorSupplier("HealthCheck"))
              .build();
        }
      }
    }
    return getHealthCheckMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static AppCallbackHealthCheckStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<AppCallbackHealthCheckStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<AppCallbackHealthCheckStub>() {
        @java.lang.Override
        public AppCallbackHealthCheckStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new AppCallbackHealthCheckStub(channel, callOptions);
        }
      };
    return AppCallbackHealthCheckStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static AppCallbackHealthCheckBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<AppCallbackHealthCheckBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<AppCallbackHealthCheckBlockingStub>() {
        @java.lang.Override
        public AppCallbackHealthCheckBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new AppCallbackHealthCheckBlockingStub(channel, callOptions);
        }
      };
    return AppCallbackHealthCheckBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static AppCallbackHealthCheckFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<AppCallbackHealthCheckFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<AppCallbackHealthCheckFutureStub>() {
        @java.lang.Override
        public AppCallbackHealthCheckFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new AppCallbackHealthCheckFutureStub(channel, callOptions);
        }
      };
    return AppCallbackHealthCheckFutureStub.newStub(factory, channel);
  }

  /**
   * <pre>
   * AppCallbackHealthCheck V1 is an optional extension to AppCallback V1 to implement
   * the HealthCheck method.
   * </pre>
   */
  public static abstract class AppCallbackHealthCheckImplBase implements io.grpc.BindableService {

    /**
     * <pre>
     * Health check.
     * </pre>
     */
    public void healthCheck(com.google.protobuf.Empty request,
        io.grpc.stub.StreamObserver<io.dapr.v1.DaprAppCallbackProtos.HealthCheckResponse> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getHealthCheckMethod(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getHealthCheckMethod(),
            io.grpc.stub.ServerCalls.asyncUnaryCall(
              new MethodHandlers<
                com.google.protobuf.Empty,
                io.dapr.v1.DaprAppCallbackProtos.HealthCheckResponse>(
                  this, METHODID_HEALTH_CHECK)))
          .build();
    }
  }

  /**
   * <pre>
   * AppCallbackHealthCheck V1 is an optional extension to AppCallback V1 to implement
   * the HealthCheck method.
   * </pre>
   */
  public static final class AppCallbackHealthCheckStub extends io.grpc.stub.AbstractAsyncStub<AppCallbackHealthCheckStub> {
    private AppCallbackHealthCheckStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected AppCallbackHealthCheckStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new AppCallbackHealthCheckStub(channel, callOptions);
    }

    /**
     * <pre>
     * Health check.
     * </pre>
     */
    public void healthCheck(com.google.protobuf.Empty request,
        io.grpc.stub.StreamObserver<io.dapr.v1.DaprAppCallbackProtos.HealthCheckResponse> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getHealthCheckMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   * <pre>
   * AppCallbackHealthCheck V1 is an optional extension to AppCallback V1 to implement
   * the HealthCheck method.
   * </pre>
   */
  public static final class AppCallbackHealthCheckBlockingStub extends io.grpc.stub.AbstractBlockingStub<AppCallbackHealthCheckBlockingStub> {
    private AppCallbackHealthCheckBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected AppCallbackHealthCheckBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new AppCallbackHealthCheckBlockingStub(channel, callOptions);
    }

    /**
     * <pre>
     * Health check.
     * </pre>
     */
    public io.dapr.v1.DaprAppCallbackProtos.HealthCheckResponse healthCheck(com.google.protobuf.Empty request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getHealthCheckMethod(), getCallOptions(), request);
    }
  }

  /**
   * <pre>
   * AppCallbackHealthCheck V1 is an optional extension to AppCallback V1 to implement
   * the HealthCheck method.
   * </pre>
   */
  public static final class AppCallbackHealthCheckFutureStub extends io.grpc.stub.AbstractFutureStub<AppCallbackHealthCheckFutureStub> {
    private AppCallbackHealthCheckFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected AppCallbackHealthCheckFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new AppCallbackHealthCheckFutureStub(channel, callOptions);
    }

    /**
     * <pre>
     * Health check.
     * </pre>
     */
    public com.google.common.util.concurrent.ListenableFuture<io.dapr.v1.DaprAppCallbackProtos.HealthCheckResponse> healthCheck(
        com.google.protobuf.Empty request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getHealthCheckMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_HEALTH_CHECK = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final AppCallbackHealthCheckImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(AppCallbackHealthCheckImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_HEALTH_CHECK:
          serviceImpl.healthCheck((com.google.protobuf.Empty) request,
              (io.grpc.stub.StreamObserver<io.dapr.v1.DaprAppCallbackProtos.HealthCheckResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class AppCallbackHealthCheckBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    AppCallbackHealthCheckBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return io.dapr.v1.DaprAppCallbackProtos.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("AppCallbackHealthCheck");
    }
  }

  private static final class AppCallbackHealthCheckFileDescriptorSupplier
      extends AppCallbackHealthCheckBaseDescriptorSupplier {
    AppCallbackHealthCheckFileDescriptorSupplier() {}
  }

  private static final class AppCallbackHealthCheckMethodDescriptorSupplier
      extends AppCallbackHealthCheckBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    AppCallbackHealthCheckMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (AppCallbackHealthCheckGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new AppCallbackHealthCheckFileDescriptorSupplier())
              .addMethod(getHealthCheckMethod())
              .build();
        }
      }
    }
    return result;
  }
}

==> dapr-sdk-autogen-1.11.0-sources.jar: io/dapr/v1/AppCallbackHealthCheckGrpc.java <==
package io.dapr.v1;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 * <pre>
 * AppCallbackHealthCheck V1 is an optional extension to AppCallback V1 to implement
 * the HealthCheck method.
 * </pre>
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.59.0)",
    comments = "Source: appcallback.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class AppCallbackHealthCheckGrpc {

  private AppCallbackHealthCheckGrpc() {}

  public static final java.lang.String SERVICE_NAME = "dapr.proto.runtime.v1.AppCallbackHealthCheck";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<com.google.protobuf.Empty,
      io.dapr.v1.DaprAppCallbackProtos.HealthCheckResponse> getHealthCheckMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "HealthCheck",
      requestType = com.google.protobuf.Empty.class,
      responseType = io.dapr.v1.DaprAppCallbackProtos.HealthCheckResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<com.google.protobuf.Empty,
      io.dapr.v1.DaprAppCallbackProtos.HealthCheckResponse> getHealthCheckMethod() {
    io.grpc.MethodDescriptor<com.google.protobuf.Empty, io.dapr.v1.DaprAppCallbackProtos.HealthCheckResponse> getHealthCheckMethod;
    if ((getHealthCheckMethod = AppCallbackHealthCheckGrpc.getHealthCheckMethod) == null) {
      synchronized (AppCallbackHealthCheckGrpc.class) {
        if ((getHealthCheckMethod = AppCallbackHealthCheckGrpc.getHealthCheckMethod) == null) {
          AppCallbackHealthCheckGrpc.getHealthCheckMethod = getHealthCheckMethod =
              io.grpc.MethodDescriptor.<com.google.protobuf.Empty, io.dapr.v1.DaprAppCallbackProtos.HealthCheckResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "HealthCheck"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.google.protobuf.Empty.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  io.dapr.v1.DaprAppCallbackProtos.HealthCheckResponse.getDefaultInstance()))
              .setSchemaDescriptor(new AppCallbackHealthCheckMethodDescriptorSupplier("HealthCheck"))
              .build();
        }
      }
    }
    return getHealthCheckMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static AppCallbackHealthCheckStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<AppCallbackHealthCheckStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<AppCallbackHealthCheckStub>() {
        @java.lang.Override
        public AppCallbackHealthCheckStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new AppCallbackHealthCheckStub(channel, callOptions);
        }
      };
    return AppCallbackHealthCheckStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static AppCallbackHealthCheckBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<AppCallbackHealthCheckBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<AppCallbackHealthCheckBlockingStub>() {
        @java.lang.Override
        public AppCallbackHealthCheckBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new AppCallbackHealthCheckBlockingStub(channel, callOptions);
        }
      };
    return AppCallbackHealthCheckBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static AppCallbackHealthCheckFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<AppCallbackHealthCheckFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<AppCallbackHealthCheckFutureStub>() {
        @java.lang.Override
        public AppCallbackHealthCheckFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new AppCallbackHealthCheckFutureStub(channel, callOptions);
        }
      };
    return AppCallbackHealthCheckFutureStub.newStub(factory, channel);
  }

  /**
   * <pre>
   * AppCallbackHealthCheck V1 is an optional extension to AppCallback V1 to implement
   * the HealthCheck method.
   * </pre>
   */
  public interface AsyncService {

    /**
     * <pre>
     * Health check.
     * </pre>
     */
    default void healthCheck(com.google.protobuf.Empty request,
        io.grpc.stub.StreamObserver<io.dapr.v1.DaprAppCallbackProtos.HealthCheckResponse> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getHealthCheckMethod(), responseObserver);
    }
  }

  /**
   * Base class for the server implementation of the service AppCallbackHealthCheck.
   * <pre>
   * AppCallbackHealthCheck V1 is an optional extension to AppCallback V1 to implement
   * the HealthCheck method.
   * </pre>
   */
  public static abstract class AppCallbackHealthCheckImplBase
      implements io.grpc.BindableService, AsyncService {

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return AppCallbackHealthCheckGrpc.bindService(this);
    }
  }

  /**
   * A stub to allow clients to do asynchronous rpc calls to service AppCallbackHealthCheck.
   * <pre>
   * AppCallbackHealthCheck V1 is an optional extension to AppCallback V1 to implement
   * the HealthCheck method.
   * </pre>
   */
  public static final class AppCallbackHealthCheckStub
      extends io.grpc.stub.AbstractAsyncStub<AppCallbackHealthCheckStub> {
    private AppCallbackHealthCheckStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected AppCallbackHealthCheckStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new AppCallbackHealthCheckStub(channel, callOptions);
    }

    /**
     * <pre>
     * Health check.
     * </pre>
     */
    public void healthCheck(com.google.protobuf.Empty request,
        io.grpc.stub.StreamObserver<io.dapr.v1.DaprAppCallbackProtos.HealthCheckResponse> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getHealthCheckMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   * A stub to allow clients to do synchronous rpc calls to service AppCallbackHealthCheck.
   * <pre>
   * AppCallbackHealthCheck V1 is an optional extension to AppCallback V1 to implement
   * the HealthCheck method.
   * </pre>
   */
  public static final class AppCallbackHealthCheckBlockingStub
      extends io.grpc.stub.AbstractBlockingStub<AppCallbackHealthCheckBlockingStub> {
    private AppCallbackHealthCheckBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected AppCallbackHealthCheckBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new AppCallbackHealthCheckBlockingStub(channel, callOptions);
    }

    /**
     * <pre>
     * Health check.
     * </pre>
     */
    public io.dapr.v1.DaprAppCallbackProtos.HealthCheckResponse healthCheck(com.google.protobuf.Empty request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getHealthCheckMethod(), getCallOptions(), request);
    }
  }

  /**
   * A stub to allow clients to do ListenableFuture-style rpc calls to service AppCallbackHealthCheck.
   * <pre>
   * AppCallbackHealthCheck V1 is an optional extension to AppCallback V1 to implement
   * the HealthCheck method.
   * </pre>
   */
  public static final class AppCallbackHealthCheckFutureStub
      extends io.grpc.stub.AbstractFutureStub<AppCallbackHealthCheckFutureStub> {
    private AppCallbackHealthCheckFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected AppCallbackHealthCheckFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new AppCallbackHealthCheckFutureStub(channel, callOptions);
    }

    /**
     * <pre>
     * Health check.
     * </pre>
     */
    public com.google.common.util.concurrent.ListenableFuture<io.dapr.v1.DaprAppCallbackProtos.HealthCheckResponse> healthCheck(
        com.google.protobuf.Empty request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getHealthCheckMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_HEALTH_CHECK = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final AsyncService serviceImpl;
    private final int methodId;

    MethodHandlers(AsyncService serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_HEALTH_CHECK:
          serviceImpl.healthCheck((com.google.protobuf.Empty) request,
              (io.grpc.stub.StreamObserver<io.dapr.v1.DaprAppCallbackProtos.HealthCheckResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  public static final io.grpc.ServerServiceDefinition bindService(AsyncService service) {
    return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
        .addMethod(
          getHealthCheckMethod(),
          io.grpc.stub.ServerCalls.asyncUnaryCall(
            new MethodHandlers<
              com.google.protobuf.Empty,
              io.dapr.v1.DaprAppCallbackProtos.HealthCheckResponse>(
                service, METHODID_HEALTH_CHECK)))
        .build();
  }

  private static abstract class AppCallbackHealthCheckBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    AppCallbackHealthCheckBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return io.dapr.v1.DaprAppCallbackProtos.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("AppCallbackHealthCheck");
    }
  }

  private static final class AppCallbackHealthCheckFileDescriptorSupplier
      extends AppCallbackHealthCheckBaseDescriptorSupplier {
    AppCallbackHealthCheckFileDescriptorSupplier() {}
  }

  private static final class AppCallbackHealthCheckMethodDescriptorSupplier
      extends AppCallbackHealthCheckBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final java.lang.String methodName;

    AppCallbackHealthCheckMethodDescriptorSupplier(java.lang.String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (AppCallbackHealthCheckGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new AppCallbackHealthCheckFileDescriptorSupplier())
              .addMethod(getHealthCheckMethod())
              .build();
        }
      }
    }
    return result;
  }
}
